rnalysis.enrichment.FeatureSet.non\_categorical\_enrichment
===========================================================

.. currentmodule:: rnalysis.enrichment

.. automethod:: FeatureSet.non_categorical_enrichment